@@ -41,7 +41,7 @@ $title = $custom_title ?: get_the_title($id);
 
                 <?php for ($i = 0; $i < 3; $i++) { ?>
                     <article class="s-mediaHead__item s-mediaHead__item--normal">
-                        <img class="me-3" src="https://via.placeholder.com/197x111?text=thumb" alt="" width="197" height="111" loading="eager">
+                        <img class="me-3" src="<?= get_template_directory_uri(); ?>/dist/images/temp-video.jpg" alt="" width="197" height="111" loading="eager">
                         <h3 class="s-mediaHead__itemTitle text-inherit fs-6 fw-normal me-auto line-clamp">
                             Video title with space for a couple of lines
                         </h3>
